part of modern_form_core;

Future<dynamic> showBottomSheetProfiles(
  context, {
  required List<ModernFormBottomSheetProfileModel> list,
  required String? title,
  TextStyle? titleStyle,
  bool? forceMenu = false,
}) async {
  if (forceMenu == null) {
    forceMenu = false;
  }
  if (MediaQuery.of(context).size.width > ModernFormUtils.webBreakdown ||
      forceMenu) {
    List<menu.PopupMenuEntry<dynamic>> items = [];

    list.forEach((element) {
      items.add(menu.PopupMenuItem(
        value: element.returnValue,
        child: _ProfileIten(
          title: element.name,
          image: element.imageUrl,
        ),
      ));
    });
    if (items.isNotEmpty) {
      return await menu.showMenu(
        context: context,
        position: menu.modernFormPopupMenuPosition(
            context, menu.ModernFormPopupMenuLocation.BottomLeft),
        items: items,
        maxHeight: MediaQuery.of(context).size.height * .3,
      );
    } else {
      return null;
    }
  }

  List<Widget> widgets = <Widget>[];
  list.forEach((element) => widgets.add(_ProfileIten(
        image: element.imageUrl,
        title: element.name,
        description: element.description,
        onTap: () {
          Navigator.pop(context, element.returnValue);
        },
      )));

  return await showModalBottomSheet(
    isScrollControlled: true,
    context: context,
    builder: (context) {
      return ConstrainedBox(
        constraints:
            BoxConstraints(maxHeight: MediaQuery.of(context).size.height * .6),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ModernFormBottonSheetLabel(
              label: title,
              labelStyle: titleStyle,
            ),
            Expanded(
              child: ListView(
                padding: EdgeInsets.symmetric(vertical: ScreenUtil().setSp(15)),
                shrinkWrap: true,
                children: widgets,
              ),
            ),
          ],
        ),
      );
    },
  );
}

class _ProfileIten extends StatelessWidget {
  final String? image;
  final String? title;
  final String? description;
  final Function()? onTap;

  const _ProfileIten(
      {Key? key, this.image, this.title, this.onTap, this.description})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: EdgeInsets.only(
            bottom: ScreenUtil().setSp(13), left: ScreenUtil().setSp(10)),
        child: InkWell(
          onTap: onTap,
          borderRadius: BorderRadius.circular(6),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Container(
                height: ScreenUtil().setHeight(50),
                width: ScreenUtil().setWidth(90),
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(6),
                  child: ImageWidget(imageUrl: image, fit: BoxFit.cover),
                ),
              ),
              SizedBox(width: ScreenUtil().setSp(8)),
              Column(
                children: [
                  Text(
                    title ?? "",
                    style: TextStyle(fontSize: ScreenUtil().setSp(15)),
                  ),
                  Text(
                    description ?? "",
                    style: TextStyle(fontSize: ScreenUtil().setSp(15)),
                  ),
                ],
              ),
            ],
          ),
        ));
  }
}
