import 'dart:io';
import 'dart:typed_data';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:modern_form/modern_form_core.dart';
import 'package:rxdart/rxdart.dart';

class ModernFormDownloadPlatformHelper {
  static Future<Uint8List?> downloadWithProgress(
    String? url, {
    void Function(int?, int)? onBytesReceived,
    Duration? timeLimit,
  }) async {
    try {
      ModernFormProgressDialog progressDialog = ModernFormProgressDialog();
      var stream = BehaviorSubject<double>.seeded(0);
      var streamText =
          BehaviorSubject<String>.seeded('Fazendo download do arquivo...');
      if (onBytesReceived == null) {
        progressDialog.showProgressDialog(
          streamValue: stream,
          streamText: streamText,
          progressColor: Colors.white,
          barrierColor: Color(0x88222222),
        );
      }
      if (url != null && url.isNotEmpty) {
        var request = await HttpClient().getUrl(Uri.parse(url));
        HttpClientResponse response = await request.close();

        if (timeLimit != null) {
          // response.timeout(timeLimit, onTimeout: (v) => null);
          response.timeout(timeLimit);
        }

        Uint8List bytes = await consolidateHttpClientResponseBytes(
          response,
          onBytesReceived: (bytesTransferred, totalByteCount) {
            if (onBytesReceived == null) {
              double percent = 0;
              percent = bytesTransferred / (totalByteCount ?? 0);
              stream.add(percent);
              streamText
                  .add("${(percent * 100).toStringAsFixed(2)}% concluído...");
            } else {
              onBytesReceived(totalByteCount, bytesTransferred);
            }
          },
        );

        stream.close();
        streamText.close();

        if (onBytesReceived == null) {
          progressDialog.dismissProgressDialog();
        }
        return bytes;
      } else {
        return null;
      }
    } catch (e) {
      print("ERROR downloadWithProgress(): $url --> $e");

      return null;
    }
  }

  static Future<Uint8List?> simpleDownload(String? url) async {
    Uint8List? bytes;

    try {
      if (url != null && url.isNotEmpty) {
        var request = await HttpClient().getUrl(Uri.parse(url));
        HttpClientResponse response = await request.close();
        bytes = await consolidateHttpClientResponseBytes(response);
      }
    } on HttpException catch (e) {
      print("ERROR simpleDownload() $url --> $e");
      print("ERROR simpleDownload() Type ${e.runtimeType}");
    }

    return bytes;
  }
}
