part of modern_form_core;

class ModernFormExpansionCard extends StatefulWidget {
  final String? label;
  final String? subTitle;
  final Color? subTitleColor;
  final Widget? child;
  final Widget? headerChild;
  final void Function(bool)? onTapOpen;
  final CrossAxisAlignment? crossAxisAlignment;

  const ModernFormExpansionCard({
    Key? key,
    this.label,
    this.child,
    this.onTapOpen,
    this.headerChild,
    this.subTitle,
    this.subTitleColor,
    this.crossAxisAlignment,
  }) : super(key: key);
  @override
  _ModernFormExpansionCardState createState() =>
      _ModernFormExpansionCardState();
}

class _ModernFormExpansionCardState extends State<ModernFormExpansionCard> {
  bool enabled = false;

  @override
  Widget build(BuildContext context) {
    Color primaryColor = Theme.of(context).primaryColor;
    return Column(
      crossAxisAlignment:
          widget.crossAxisAlignment ?? CrossAxisAlignment.center,
      children: <Widget>[
        Material(
          color: enabled ? primaryColor : Colors.white,
          shape:
              RoundedRectangleBorder(borderRadius: BorderRadius.circular(4.0)),
          elevation: 4.0,
          child: InkWell(
            onTap: () {
              setState(() {
                enabled = !enabled;
              });
              if (widget.onTapOpen != null) {
                widget.onTapOpen!(enabled);
              }
            },
            borderRadius: BorderRadius.circular(4.0),
            child: Padding(
              padding: EdgeInsets.symmetric(vertical: ScreenUtil().setSp(10)),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Padding(
                    padding: EdgeInsets.only(left: ScreenUtil().setSp(10)),
                    child: ConstrainedBox(
                      constraints: BoxConstraints(
                        maxWidth: ScreenUtil().screenWidth * .6,
                      ),
                      child: Wrap(
                        children: [
                          Text(
                            widget.label ?? "",
                            style: TextStyle(
                              color: enabled ? Colors.white : Colors.black,
                            ),
                          ),
                          widget.subTitle != null
                              ? Padding(
                                  padding: EdgeInsets.only(
                                      left: ScreenUtil().setSp(10)),
                                  child: Text(
                                    widget.subTitle ?? "",
                                    style: TextStyle(
                                      color: enabled
                                          ? Colors.white
                                          : widget.subTitleColor ??
                                              Colors.black,
                                    ),
                                  ),
                                )
                              : Container(),
                        ],
                      ),
                    ),
                  ),
                  Row(
                    children: <Widget>[
                      widget.headerChild != null && enabled
                          ? widget.headerChild!
                          : Container(),
                      Padding(
                        padding: EdgeInsets.only(right: ScreenUtil().setSp(10)),
                        child: Icon(
                          enabled ? Icons.arrow_drop_up : Icons.arrow_drop_down,
                          color: enabled ? Colors.white : Colors.black,
                        ),
                      ),
                    ],
                  ),
                ],
              ),
            ),
          ),
        ),
        AnimatedCrossFade(
          crossFadeState:
              enabled ? CrossFadeState.showFirst : CrossFadeState.showSecond,
          duration: Duration(milliseconds: 400),
          firstChild: enabled
              ? widget.child != null
                  ? widget.child!
                  : SizedBox()
              : SizedBox(),
          secondChild: SizedBox(),
        ),
        // AnimatedOpacity(
        //   duration: Duration(seconds: 1),
        //   opacity: enabled ? 1 : 0,
        //   child: enabled ? widget.child ?? Container() : Container(),
        // ),
      ],
    );
  }
}
