part of modern_form_core;

class ModernFormConstrainedText extends StatelessWidget {
  final String? text;
  final double? maxWidth;
  final TextStyle? style;
  final bool? selectableDisabled;
  final TextAlign? alignment;
  final int? maxLines;
  final TextOverflow? overflow;

  const ModernFormConstrainedText(
    this.text, {
    Key? key,
    this.maxWidth,
    this.style,
    this.selectableDisabled,
    this.alignment,
    this.maxLines,
    this.overflow,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    bool _selectableDisabled =
        selectableDisabled != null && selectableDisabled!;

    return ConstrainedBox(
      constraints:
          BoxConstraints(maxWidth: ScreenUtil().screenWidth * (maxWidth ?? .7)),
      child: Wrap(
        alignment: alignment?.toWrapAlignment ?? WrapAlignment.start,
        children: [
          _selectableDisabled
              ? Text(
                  text ?? "",
                  style: style,
                  textAlign: alignment,
                  maxLines: maxLines,
                  overflow: overflow,
                )
              : SelectableText(
                  text ?? "",
                  style: style,
                  textAlign: alignment,
                  maxLines: maxLines,
                ),
        ],
      ),
    );
  }
}

extension TextAlignExtension on TextAlign? {
  WrapAlignment get toWrapAlignment {
    switch (this) {
      case TextAlign.left:
        return WrapAlignment.start;
      case TextAlign.right:
        return WrapAlignment.end;
      case TextAlign.center:
        return WrapAlignment.center;
      case TextAlign.justify:
        return WrapAlignment.center;
      case TextAlign.start:
        return WrapAlignment.start;
      case TextAlign.end:
        return WrapAlignment.end;
      default:
        return WrapAlignment.start;
    }
  }
}
