part of modern_form_core;

class ModernFormFakeTextField extends StatelessWidget {
  final void Function(String)? onChanged;
  final String? label;
  final String? helperText;
  final TextStyle Function(TextStyle)? textStyle;
  final TextStyle Function(TextStyle)? labelStyle;
  final TextStyle Function(TextStyle)? errorStyle;
  final InputDecoration Function(InputDecoration)? decoration;
  final Icon? prefixIcon;
  final String? initialValue;
  final void Function()? onTap;
  final bool sufixIconEnabled;
  final bool? enabled;
  final Widget? child;
  final bool? isEmpty;
  final String? Function(dynamic)? validator;
  final Widget? suffixIcon;

  ModernFormFakeTextField({
    this.onChanged,
    this.label,
    this.textStyle,
    this.labelStyle,
    this.prefixIcon,
    this.initialValue,
    this.onTap,
    this.sufixIconEnabled = true,
    this.enabled = true,
    this.child,
    this.isEmpty,
    this.validator,
    this.decoration,
    this.errorStyle,
    this.suffixIcon,
    this.helperText,
  });

  @override
  Widget build(BuildContext context) {
    InputDecoration inputDecoration = InputDecoration(
      errorText: validator != null ? validator!(initialValue) : null,
      errorStyle: errorStyle != null
          ? errorStyle!(ModernFormTextStyle.moderFormErrorStyle)
          : ModernFormTextStyle.moderFormErrorStyle,
      helperText: helperText,
      helperMaxLines: 9999,
      enabled: enabled ?? true,
      labelText: label ?? "",
      labelStyle: labelStyle != null
          ? labelStyle!(ModernFormTextStyle.moderFormLabelStyle)
          : ModernFormTextStyle.moderFormLabelStyle,
      prefixIcon: prefixIcon,
      suffixIcon: sufixIconEnabled &&
              initialValue != null &&
              initialValue!.isNotEmpty &&
              (enabled ?? true)
          ? InkWell(
              onTap: () {
                if (onChanged != null) {
                  onChanged!("");
                }
              },
              borderRadius: BorderRadius.circular(40),
              child: Padding(
                padding: EdgeInsets.all(ScreenUtil().setSp(8)),
                child: Icon(
                  Icons.close,
                  color: initialValue != null && initialValue!.isNotEmpty
                      ? Colors.grey
                      : Colors.transparent,
                ),
              ),
            )
          : suffixIcon != null
              ? suffixIcon
              : null,
    );

    return InkWell(
      onTap: enabled ?? true ? onTap : null,
      child: InputDecorator(
        isEmpty: isEmpty != null
            ? isEmpty!
            : !(initialValue != null && initialValue!.isNotEmpty),
        decoration:
            decoration != null ? decoration!(inputDecoration) : inputDecoration,
        child: child ??
            SelectableText(
              initialValue ?? "",
              style: textStyle != null
                  ? textStyle!(ModernFormTextStyle.moderFormTextStyle)
                  : ModernFormTextStyle.moderFormTextStyle,
              onTap: enabled ?? true ? onTap : null,
            ),
      ),
    );
  }
}
