part of modern_form_core;

enum ModernFormTextFieldListennerType { Text, Money, Number, Percent }

extension ModernFormTextFieldListennerTypeExtensions
    on ModernFormTextFieldListennerType? {
  TextInputType get toKeyboardType {
    switch (this) {
      case ModernFormTextFieldListennerType.Text:
        return TextInputType.text;
      case ModernFormTextFieldListennerType.Money:
        return TextInputType.number;
      case ModernFormTextFieldListennerType.Number:
        return TextInputType.number;
      case ModernFormTextFieldListennerType.Percent:
        return TextInputType.number;
      default:
        return TextInputType.text;
    }
  }
}

extension ModernFormTextFieldListennerExtensions
    on ModernFormTextFieldListenner {
  TextEditingController toController() {
    switch (this.type) {
      case ModernFormTextFieldListennerType.Text:
        if (this.mask != null) {
          return MaskedTextController(
              mask: this.mask!, text: this.value?.toString() ?? "");
        }
        return TextEditingController(text: this.value?.toString() ?? "");
      case ModernFormTextFieldListennerType.Money:
        return MoneyMaskedTextController(
          initialValue: this.value is num ? this.value.toDouble() : 0.0,
          rightSymbol: this.rightSymbol ?? '',
          leftSymbol: this.leftSymbol ?? "R\$ ",
          decimalSeparator: this.decimalSeparator ?? ",",
        );
      case ModernFormTextFieldListennerType.Number:
        return MoneyMaskedTextController(
          initialValue: this.value is num ? this.value.toDouble() : 0.0,
          precision: this.precision ?? 0,
          decimalSeparator: this.decimalSeparator != null
              ? this.decimalSeparator!
              : (this.precision == null || this.precision == 0)
                  ? ""
                  : ",",
          leftSymbol: this.leftSymbol ?? '',
          rightSymbol: this.rightSymbol ?? '',
        );
      case ModernFormTextFieldListennerType.Percent:
        return MoneyMaskedTextController(
          initialValue: value is num ? value?.toDouble() ?? 0.0 : 0.0,
          precision: this.precision ?? 2,
          decimalSeparator: this.decimalSeparator != null
              ? this.decimalSeparator!
              : (this.precision == null || this.precision == 2)
                  ? ""
                  : ",",
          rightSymbol: this.rightSymbol ?? "%",
          leftSymbol: this.leftSymbol ?? '',
        );
      default:
        return TextEditingController(text: this.value?.toString() ?? "");
    }
  }
}
