part of modern_form_files;

class ModernFormFilePicker extends StatelessWidget {
  final String? label;
  final void Function(Uint8List)? onChanged;
  final void Function(String url)? onChangePaste;
  final Widget? child;
  final bool? enabled;
  final Uint8List? arquive;
  final String? arquiveUrl;
  final String? arquiveName;
  final ModernFormFileExtensionType? fileExtensionType;
  final String? Function(Uint8List?)? validator;
  final void Function(ModernFormFileExtensionType)? onChangedFileType;
  final bool? pasteEnabled;

  const ModernFormFilePicker({
    Key? key,
    this.label,
    this.onChanged,
    this.child,
    this.enabled,
    this.arquive,
    this.arquiveName,
    this.fileExtensionType,
    this.validator,
    this.onChangedFileType,
    this.arquiveUrl,
    this.onChangePaste,
    this.pasteEnabled,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool isArquiveExist = (arquive != null && arquive!.isNotEmpty) ||
        (arquiveUrl != null && arquiveUrl!.isNotEmpty);

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(label ?? "Arquivo",
            style: ModernFormTextStyle.moderFormLabelStyle),
        validator != null && validator!(arquive) != null
            ? Text(validator!(arquive) ?? "",
                style: ModernFormTextStyle.moderFormErrorStyle)
            : Container(),
        SizedBox(height: ScreenUtil().setHeight(2)),
        Padding(
          padding: EdgeInsets.all(ScreenUtil().setSp(8)),
          child: Column(
            children: [
              ModernFormTextPicker<ModernFormFileExtensionType>(
                label: "Tipo de arquivo",
                list: ModernFormFileExtensionType.values
                    .map((e) =>
                        ModernFormBottomSheetModel<ModernFormFileExtensionType>(
                            text: e.toValueString, value: e))
                    .toList(),
                value: fileExtensionType?.toValueString ?? "",
                onChanged: onChangedFileType,
              ),
              SizedBox(height: ScreenUtil().setHeight(15)),
              Row(
                children: [
                  child == null
                      ? isArquiveExist
                          ? Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(20)),
                              child: ModernFormViewFile(
                                file: arquive,
                                fileUrl: arquiveUrl,
                                fileName: arquiveName,
                                fileExtensionType: fileExtensionType,
                              ),
                            )
                          : Container()
                      : child!,
                  ModernFormUpload(
                    onTap: (enabled ?? true)
                        ? fileExtensionType == null
                            ? () {
                                showFlushBar(
                                  value: false,
                                  textFalse: "Selecione o tipo de arquivo",
                                );
                              }
                            : () async {
                                Uint8List? data =
                                    await ModernFormFileHelper.getFile(
                                        fileExtensionType);

                                if (data != null && onChanged != null) {
                                  onChanged!(data);
                                }
                              }
                        : null,
                    pasteEnabled: pasteEnabled,
                    onChange: (enabled ?? true) && onChangePaste != null
                        ? (value) {
                            if (fileExtensionType == null) {
                              showFlushBar(
                                value: false,
                                textFalse: "Selecione o tipo de arquivo",
                              );
                            } else {
                              onChangePaste!(value);
                            }
                          }
                        : null,
                  ),
                ],
              ),
            ],
          ),
        ),
      ],
    );
  }
}
