part of modern_form_images;

void showModernFormImageFullScreen({
  String? networkImage,
  Uint8List? memoryImage,
  Color? color,
  String? tag,
  String? name,
}) {
  ModernFormNavigation.pushPage(HeroPhotoViewWrapper(
    networkImage: networkImage,
    memoryImage: memoryImage,
    color: color,
    tag: tag,
    name: name,
  ));
}

class HeroPhotoViewWrapper extends StatelessWidget {
  final String? networkImage;
  final Uint8List? memoryImage;
  final Color? color;
  final String? tag;
  final String? name;

  const HeroPhotoViewWrapper({
    Key? key,
    this.networkImage,
    this.memoryImage,
    this.color,
    this.tag,
    this.name,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
          icon: Icon(Icons.close, color: Colors.white),
          onPressed: ModernFormNavigation.pop,
        ),
        actions: [
          IconButton(
            icon: Icon(Icons.share, size: ScreenUtil().setSp(18)),
            onPressed: () {
              if (memoryImage != null) {
                ModernFormImageHelper.shareImage(
                  memoryImage!,
                  name ?? "",
                  name: name,
                );
              } else if (networkImage != null) {
                ModernFormImageHelper.shareImageFromUrl(
                  networkImage,
                  name ?? "",
                );
              }
            },
          )
        ],
      ),
      body: Container(
        height: MediaQuery.of(context).size.height,
        child: PhotoView(
          loadingBuilder: (context, ImageChunkEvent? imageChunkEvent) {
            int total = imageChunkEvent?.expectedTotalBytes ?? 0;
            int actual = imageChunkEvent?.cumulativeBytesLoaded ?? 0;

            double percent = (actual) / total;
            if (percent.isInfinite || percent.isNaN) {
              percent = 0;
            }

            return ModernFormProgressIndicator(
                value: percent, color: Theme.of(context).primaryColor);
          },
          backgroundDecoration: BoxDecoration(color: color),
          imageProvider: imageProviderWidget(
            imageUrl: networkImage,
            imageMemory: memoryImage,
          ),
          heroAttributes:
              PhotoViewHeroAttributes(tag: tag ?? networkImage ?? ""),
        ),
      ),
    );
  }
}
