part of modern_form_videos;

class ModernFormVideoPlayer extends StatefulWidget {
  final FlickManager? flickManager;
  final void Function(BuildContext context)? share;
  final void Function()? shareUrl;
  final void Function()? shareArquive;
  final void Function()? downloadArquive;

  const ModernFormVideoPlayer({
    Key? key,
    this.flickManager,
    this.share,
    this.shareUrl,
    this.shareArquive,
    this.downloadArquive,
  }) : super(key: key);

  @override
  _ModernFormVideoPlayerState createState() => _ModernFormVideoPlayerState();
}

class _ModernFormVideoPlayerState extends State<ModernFormVideoPlayer> {
  FlickManager? flickManager;

  @override
  void initState() {
    super.initState();
    flickManager = widget.flickManager;
  }

  @override
  void dispose() {
    flickManager!.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;

    Widget shareIcon(double? s) => Row(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            Builder(
              builder: (context) => IconButton(
                icon: Icon(Icons.share, size: ScreenUtil().setSp(s ?? 18)),
                onPressed: () {
                  widget.share!(context);
                },
              ),
            )
          ],
        );

    if (flickManager == null) {
      return Container();
    }

    return Container(
      height:
          size.width > ModernFormUtils.webBreakdown ? size.height * .6 : null,
      child: VisibilityDetector(
        key: ObjectKey(flickManager),
        onVisibilityChanged: (visibility) {
          if (visibility.visibleFraction == 0 && this.mounted) {
            flickManager!.flickControlManager!.autoPause();
          } else if (visibility.visibleFraction == 1) {
            flickManager!.flickControlManager!.autoResume();
          }
        },
        child: FlickVideoPlayer(
          flickManager: flickManager!,
          systemUIOverlayFullscreen: [],
          flickVideoWithControls: FlickVideoWithControls(
            videoFit: BoxFit.fill,
            controls: Stack(
              children: [
                CustomFlickPortraitControls(
                  flickManager: flickManager,
                  shareIcon: shareIcon,
                ),
                shareIcon(18),
              ],
            ),
          ),
          flickVideoWithControlsFullscreen: FlickVideoWithControls(
            videoFit: BoxFit.fill,
            controls: Stack(
              children: [
                FlickLandscapeControls(),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    IconButton(
                      icon: Icon(Icons.close, size: ScreenUtil().setSp(22)),
                      onPressed: () {
                        // SystemChrome.setEnabledSystemUIOverlays(
                        // SystemUiOverlay.values);
                        // SystemChrome.restoreSystemUIOverlays();
                        // SystemChrome.setPreferredOrientations(
                        // [DeviceOrientation.portraitUp]);
                        flickManager!.flickControlManager!.exitFullscreen();
                      },
                    ),
                    shareIcon(22),
                  ],
                ),
              ],
            ),
          ),
          preferredDeviceOrientation: [
            DeviceOrientation.landscapeLeft,
            DeviceOrientation.landscapeRight,
            DeviceOrientation.portraitDown,
            DeviceOrientation.portraitUp,
          ],
          preferredDeviceOrientationFullscreen: [
            DeviceOrientation.landscapeLeft,
            DeviceOrientation.landscapeRight,
            DeviceOrientation.portraitDown,
            DeviceOrientation.portraitUp,
          ],
        ),
      ),
    );
  }
}
